@@ -1,14 +1,22 @@
 <?php
 
+namespace MediaWiki\Extension\Scribunto\Engines\LuaStandalone;
+
+use MediaWiki\Extension\Scribunto\ScribuntoException;
+use MWException;
 use Psr\Log\LoggerInterface;
 use Psr\Log\NullLogger;
+use Scribunto_LuaError;
+use Scribunto_LuaInterpreter;
+use Scribunto_LuaInterpreterNotFoundError;
+use UtfNormal\Validator;
 
-class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
+class LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 	/** @var int */
 	protected static $nextInterpreterId = 0;
 
 	/**
-	 * @var Scribunto_LuaStandaloneEngine
+	 * @var LuaStandaloneEngine
 	 */
 	public $engine;
 
@@ -53,7 +61,7 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 	protected $callbacks;
 
 	/**
-	 * @param Scribunto_LuaStandaloneEngine $engine
+	 * @param LuaStandaloneEngine $engine
 	 * @param array $options
 	 * @throws MWException
 	 * @throws Scribunto_LuaInterpreterNotFoundError
@@ -114,11 +122,14 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 		if ( php_uname( 's' ) == 'Linux' ) {
 			// Limit memory and CPU
 			$cmd = wfEscapeShellArg(
-				'exec', # proc_open() passes $cmd to 'sh -c' on Linux, so add an 'exec' to bypass it
+				# proc_open() passes $cmd to 'sh -c' on Linux, so add an 'exec' to bypass it
+				'exec',
 				'/bin/sh',
 				__DIR__ . '/lua_ulimit.sh',
-				(string)$options['cpuLimit'], # soft limit (SIGXCPU)
-				(string)( $options['cpuLimit'] + 1 ), # hard limit
+				# soft limit (SIGXCPU)
+				(string)$options['cpuLimit'],
+				# hard limit
+				(string)( $options['cpuLimit'] + 1 ),
 				(string)intval( $options['memoryLimit'] / 1024 ),
 				$cmd );
 		}
@@ -180,7 +191,7 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 			if ( PHP_OS == 'Linux' ) {
 				return 'Lua 5.1.5';
 			} elseif ( PHP_OS == 'Windows' || PHP_OS == 'WINNT' || PHP_OS == 'Win32' ) {
-				return 'Lua 5.1.4';
+				return 'Lua 5.1.5';
 			} elseif ( PHP_OS == 'Darwin' ) {
 				return 'Lua 5.1.5';
 			} else {
@@ -232,7 +243,7 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 	/**
 	 * @param string $text
 	 * @param string $chunkName
-	 * @return Scribunto_LuaStandaloneInterpreterFunction
+	 * @return LuaStandaloneInterpreterFunction
 	 */
 	public function loadString( $text, $chunkName ) {
 		$this->cleanupLuaChunks();
@@ -242,12 +253,12 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 			'text' => $text,
 			'chunkName' => $chunkName
 		] );
-		return new Scribunto_LuaStandaloneInterpreterFunction( $this->id, $result[1] );
+		return new LuaStandaloneInterpreterFunction( $this->id, $result[1] );
 	}
 
 	/** @inheritDoc */
 	public function callFunction( $func, ...$args ) {
-		if ( !( $func instanceof Scribunto_LuaStandaloneInterpreterFunction ) ) {
+		if ( !( $func instanceof LuaStandaloneInterpreterFunction ) ) {
 			throw new MWException( __METHOD__ . ': invalid function type' );
 		}
 		if ( $func->interpreterId !== $this->id ) {
@@ -282,18 +293,18 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 	}
 
 	public function cleanupLuaChunks() {
-		if ( isset( Scribunto_LuaStandaloneInterpreterFunction::$anyChunksDestroyed[$this->id] ) ) {
-			unset( Scribunto_LuaStandaloneInterpreterFunction::$anyChunksDestroyed[$this->id] );
+		if ( isset( LuaStandaloneInterpreterFunction::$anyChunksDestroyed[$this->id] ) ) {
+			unset( LuaStandaloneInterpreterFunction::$anyChunksDestroyed[$this->id] );
 			$this->dispatch( [
 				'op' => 'cleanupChunks',
-				'ids' => Scribunto_LuaStandaloneInterpreterFunction::$activeChunkIds[$this->id]
+				'ids' => LuaStandaloneInterpreterFunction::$activeChunkIds[$this->id]
 			] );
 		}
 	}
 
 	/** @inheritDoc */
 	public function isLuaFunction( $object ) {
-		return $object instanceof Scribunto_LuaStandaloneInterpreterFunction;
+		return $object instanceof LuaStandaloneInterpreterFunction;
 	}
 
 	/** @inheritDoc */
@@ -394,15 +405,25 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 	 * Converts the encoded Lua error to an appropriate exception and throws it.
 	 *
 	 * @param array $message
+	 * @return never
 	 */
 	protected function handleError( $message ) {
 		$opts = [];
+		$message['value'] = Validator::cleanUp( $message['value'] );
 		if ( preg_match( '/^(.*?):(\d+): (.*)$/', $message['value'], $m ) ) {
 			$opts['module'] = $m[1];
 			$opts['line'] = $m[2];
 			$message['value'] = $m[3];
 		}
 		if ( isset( $message['trace'] ) ) {
+			foreach ( $message['trace'] as &$val ) {
+				$val = array_map( static function ( $val ) {
+					if ( is_string( $val ) ) {
+						$val = Validator::cleanUp( $val );
+					}
+					return $val;
+				}, $val );
+			}
 			$opts['trace'] = array_values( $message['trace'] );
 		}
 		throw $this->engine->newLuaError( $message['value'], $opts );
@@ -427,7 +448,7 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 					break;
 				case 'error':
 					$this->handleError( $msgFromLua );
-					return [];
+					// handleError prevents continuation
 				default:
 					$this->logger->error( __METHOD__ . ": invalid response op \"{$msgFromLua['op']}\"" );
 					throw $this->engine->newException( 'scribunto-luastandalone-decode-error' );
@@ -560,7 +581,7 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 				$s .= '}';
 				return $s;
 			case 'object':
-				if ( !( $var instanceof Scribunto_LuaStandaloneInterpreterFunction ) ) {
+				if ( !( $var instanceof LuaStandaloneInterpreterFunction ) ) {
 					throw new MWException( __METHOD__ . ': unable to convert object of type ' .
 						get_class( $var ) );
 				} elseif ( $var->interpreterId !== $this->id ) {
@@ -626,6 +647,7 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 			$status = proc_get_status( $this->proc );
 			// XXX: Should proc_get_status docs be changed so that
 			// its documented as possibly returning false?
+			// @phan-suppress-next-line PhanTypeComparisonFromArray
 			if ( $status === false ) {
 				// WTF? Let the caller throw an appropriate error.
 				return;
@@ -633,7 +655,8 @@ class Scribunto_LuaStandaloneInterpreter extends Scribunto_LuaInterpreter {
 			if ( !$status['running'] ) {
 				break;
 			}
-			usleep( 10000 ); // Give the killed process a chance to be scheduled
+			// Give the killed process a chance to be scheduled
+			usleep( 10000 );
 		}
 		proc_close( $this->proc );
 		$this->proc = false;
